# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: pqc.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'pqc.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\tpqc.proto\x12\x06pqc.v1\"\x1c\n\x0cStoreRequest\x12\x0c\n\x04\x64\x61ta\x18\x01 \x01(\x0c\"#\n\rStoreResponse\x12\x12\n\nmessage_id\x18\x01 \x01(\t\"%\n\x0fRetrieveRequest\x12\x12\n\nmessage_id\x18\x01 \x01(\t\" \n\x10RetrieveResponse\x12\x0c\n\x04\x64\x61ta\x18\x01 \x01(\x0c\x32\x81\x01\n\nPQCService\x12\x34\n\x05Store\x12\x14.pqc.v1.StoreRequest\x1a\x15.pqc.v1.StoreResponse\x12=\n\x08Retrieve\x12\x17.pqc.v1.RetrieveRequest\x1a\x18.pqc.v1.RetrieveResponseb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'pqc_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_STOREREQUEST']._serialized_start=21
  _globals['_STOREREQUEST']._serialized_end=49
  _globals['_STORERESPONSE']._serialized_start=51
  _globals['_STORERESPONSE']._serialized_end=86
  _globals['_RETRIEVEREQUEST']._serialized_start=88
  _globals['_RETRIEVEREQUEST']._serialized_end=125
  _globals['_RETRIEVERESPONSE']._serialized_start=127
  _globals['_RETRIEVERESPONSE']._serialized_end=159
  _globals['_PQCSERVICE']._serialized_start=162
  _globals['_PQCSERVICE']._serialized_end=291
# @@protoc_insertion_point(module_scope)
