# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
import warnings

from . import pqc_pb2 as pqc__pb2

GRPC_GENERATED_VERSION = '1.76.0'
GRPC_VERSION = grpc.__version__
_version_not_supported = False

try:
    from grpc._utilities import first_version_is_lower
    _version_not_supported = first_version_is_lower(GRPC_VERSION, GRPC_GENERATED_VERSION)
except ImportError:
    _version_not_supported = True

if _version_not_supported:
    raise RuntimeError(
        f'The grpc package installed is at version {GRPC_VERSION},'
        + ' but the generated code in pqc_pb2_grpc.py depends on'
        + f' grpcio>={GRPC_GENERATED_VERSION}.'
        + f' Please upgrade your grpc module to grpcio>={GRPC_GENERATED_VERSION}'
        + f' or downgrade your generated code using grpcio-tools<={GRPC_VERSION}.'
    )


class PQCServiceStub(object):
    """--- Service Definition ---

    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Store = channel.unary_unary(
                '/pqc.v1.PQCService/Store',
                request_serializer=pqc__pb2.StoreRequest.SerializeToString,
                response_deserializer=pqc__pb2.StoreResponse.FromString,
                _registered_method=True)
        self.Retrieve = channel.unary_unary(
                '/pqc.v1.PQCService/Retrieve',
                request_serializer=pqc__pb2.RetrieveRequest.SerializeToString,
                response_deserializer=pqc__pb2.RetrieveResponse.FromString,
                _registered_method=True)


class PQCServiceServicer(object):
    """--- Service Definition ---

    """

    def Store(self, request, context):
        """Stores a piece of data and returns a unique ID for it.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Retrieve(self, request, context):
        """Retrieves a piece of data using its unique ID.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_PQCServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Store': grpc.unary_unary_rpc_method_handler(
                    servicer.Store,
                    request_deserializer=pqc__pb2.StoreRequest.FromString,
                    response_serializer=pqc__pb2.StoreResponse.SerializeToString,
            ),
            'Retrieve': grpc.unary_unary_rpc_method_handler(
                    servicer.Retrieve,
                    request_deserializer=pqc__pb2.RetrieveRequest.FromString,
                    response_serializer=pqc__pb2.RetrieveResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'pqc.v1.PQCService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('pqc.v1.PQCService', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class PQCService(object):
    """--- Service Definition ---

    """

    @staticmethod
    def Store(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/pqc.v1.PQCService/Store',
            pqc__pb2.StoreRequest.SerializeToString,
            pqc__pb2.StoreResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Retrieve(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/pqc.v1.PQCService/Retrieve',
            pqc__pb2.RetrieveRequest.SerializeToString,
            pqc__pb2.RetrieveResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)
