# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: pqc.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'pqc.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\tpqc.proto\x12\x03pqc\"S\n\x11UploadFileRequest\x12%\n\x08metadata\x18\x01 \x01(\x0b\x32\x11.pqc.FileMetadataH\x00\x12\x0f\n\x05\x63hunk\x18\x02 \x01(\x0cH\x00\x42\x06\n\x04\x64\x61ta\" \n\x0c\x46ileMetadata\x12\x10\n\x08\x66ilename\x18\x01 \x01(\t\".\n\x12UploadFileResponse\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04size\x18\x02 \x01(\x04\"!\n\x13\x44ownloadFileRequest\x12\n\n\x02id\x18\x01 \x01(\t\"%\n\x14\x44ownloadFileResponse\x12\r\n\x05\x63hunk\x18\x01 \x01(\x0c\"\x12\n\x10RotateKeyRequest\"#\n\x11RotateKeyResponse\x12\x0e\n\x06status\x18\x01 \x01(\t\"\x1f\n\x0cStoreRequest\x12\x0f\n\x07message\x18\x01 \x01(\t\"\x1b\n\rStoreResponse\x12\n\n\x02id\x18\x01 \x01(\x04\"\x1d\n\x0fRetrieveRequest\x12\n\n\x02id\x18\x01 \x01(\x04\"#\n\x10RetrieveResponse\x12\x0f\n\x07message\x18\x01 \x01(\t2\xbd\x02\n\x0ePQCStringStore\x12.\n\x05Store\x12\x11.pqc.StoreRequest\x1a\x12.pqc.StoreResponse\x12\x37\n\x08Retrieve\x12\x14.pqc.RetrieveRequest\x1a\x15.pqc.RetrieveResponse\x12:\n\tRotateKey\x12\x15.pqc.RotateKeyRequest\x1a\x16.pqc.RotateKeyResponse\x12?\n\nUploadFile\x12\x16.pqc.UploadFileRequest\x1a\x17.pqc.UploadFileResponse(\x01\x12\x45\n\x0c\x44ownloadFile\x12\x18.pqc.DownloadFileRequest\x1a\x19.pqc.DownloadFileResponse0\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'pqc_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_UPLOADFILEREQUEST']._serialized_start=18
  _globals['_UPLOADFILEREQUEST']._serialized_end=101
  _globals['_FILEMETADATA']._serialized_start=103
  _globals['_FILEMETADATA']._serialized_end=135
  _globals['_UPLOADFILERESPONSE']._serialized_start=137
  _globals['_UPLOADFILERESPONSE']._serialized_end=183
  _globals['_DOWNLOADFILEREQUEST']._serialized_start=185
  _globals['_DOWNLOADFILEREQUEST']._serialized_end=218
  _globals['_DOWNLOADFILERESPONSE']._serialized_start=220
  _globals['_DOWNLOADFILERESPONSE']._serialized_end=257
  _globals['_ROTATEKEYREQUEST']._serialized_start=259
  _globals['_ROTATEKEYREQUEST']._serialized_end=277
  _globals['_ROTATEKEYRESPONSE']._serialized_start=279
  _globals['_ROTATEKEYRESPONSE']._serialized_end=314
  _globals['_STOREREQUEST']._serialized_start=316
  _globals['_STOREREQUEST']._serialized_end=347
  _globals['_STORERESPONSE']._serialized_start=349
  _globals['_STORERESPONSE']._serialized_end=376
  _globals['_RETRIEVEREQUEST']._serialized_start=378
  _globals['_RETRIEVEREQUEST']._serialized_end=407
  _globals['_RETRIEVERESPONSE']._serialized_start=409
  _globals['_RETRIEVERESPONSE']._serialized_end=444
  _globals['_PQCSTRINGSTORE']._serialized_start=447
  _globals['_PQCSTRINGSTORE']._serialized_end=764
# @@protoc_insertion_point(module_scope)
